import { z } from 'zod';
export declare const TypescriptPluginConfigSchema: z.ZodDefault<z.ZodAny>;
export type TypescriptPluginConfig = z.infer<typeof TypescriptPluginConfigSchema>;
export type TypescriptPluginInputConfig = z.input<typeof TypescriptPluginConfigSchema>;
export declare const ConfigSchema: z.ZodObject<{
    schema: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>;
    buildProperties: z.ZodDefault<z.ZodObject<{
        external: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
        minify: z.ZodDefault<z.ZodBoolean>;
        sourcemap: z.ZodDefault<z.ZodBoolean>;
        target: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        external: string[];
        minify: boolean;
        sourcemap: boolean;
        target: string;
    }, {
        external?: string[] | undefined;
        minify?: boolean | undefined;
        sourcemap?: boolean | undefined;
        target?: string | undefined;
    }>>;
    outputConfig: z.ZodDefault<z.ZodObject<{
        format: z.ZodDefault<z.ZodEnum<["json", "yaml"]>>;
        yamlConfig: z.ZodDefault<z.ZodObject<{
            condenseFlow: z.ZodOptional<z.ZodBoolean>;
            flowLevel: z.ZodOptional<z.ZodNumber>;
            forceQuotes: z.ZodDefault<z.ZodBoolean>;
            indent: z.ZodOptional<z.ZodNumber>;
            lineWidth: z.ZodOptional<z.ZodNumber>;
            noArrayIndent: z.ZodOptional<z.ZodBoolean>;
            noCompatMode: z.ZodOptional<z.ZodBoolean>;
            noRefs: z.ZodDefault<z.ZodBoolean>;
            quotingType: z.ZodDefault<z.ZodEnum<["'", "\""]>>;
            skipInvalid: z.ZodOptional<z.ZodBoolean>;
            sortKeys: z.ZodDefault<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        }, {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        format: "json" | "yaml";
        yamlConfig: {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        };
    }, {
        format?: "json" | "yaml" | undefined;
        yamlConfig?: {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        } | undefined;
    }>>;
    sourceTemplate: z.ZodOptional<z.ZodString>;
    cloudformationTemplate: z.ZodString;
    typescriptConfig: z.ZodDefault<z.ZodAny>;
    typescriptOutput: z.ZodString;
    actionsModuleId: z.ZodString;
    dependenciesModuleId: z.ZodString;
    dispatcherDefaults: z.ZodDefault<z.ZodObject<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
        batchSize: z.ZodDefault<z.ZodNumber>;
        maximumRetryAttempts: z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
        batchSize: number;
        maximumRetryAttempts: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
        batchSize?: number | undefined;
        maximumRetryAttempts?: number | undefined;
    }>>;
    handlerDefaults: z.ZodDefault<z.ZodObject<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    lambdaDefaults: z.ZodDefault<z.ZodObject<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    tableDefaults: z.ZodDefault<z.ZodObject<{
        enablePointInTimeRecovery: z.ZodDefault<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        enablePointInTimeRecovery: boolean;
    }, {
        enablePointInTimeRecovery?: boolean | undefined;
    }>>;
    useEfficientIndexes: z.ZodDefault<z.ZodBoolean>;
    legacyEmptySortFieldBehavior: z.ZodDefault<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    schema: (string | string[]) & (string | string[] | undefined);
    dependenciesModuleId: string;
    dispatcherDefaults: {
        memorySize: number;
        timeout: number;
        batchSize: number;
        maximumRetryAttempts: number;
    };
    handlerDefaults: {
        memorySize: number;
        timeout: number;
    };
    lambdaDefaults: {
        memorySize: number;
        timeout: number;
    };
    tableDefaults: {
        enablePointInTimeRecovery: boolean;
    };
    useEfficientIndexes: boolean;
    actionsModuleId: string;
    buildProperties: {
        external: string[];
        minify: boolean;
        sourcemap: boolean;
        target: string;
    };
    outputConfig: {
        format: "json" | "yaml";
        yamlConfig: {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        };
    };
    legacyEmptySortFieldBehavior: boolean;
    cloudformationTemplate: string;
    typescriptOutput: string;
    sourceTemplate?: string | undefined;
    typescriptConfig?: any;
}, {
    schema: (string | string[]) & (string | string[] | undefined);
    dependenciesModuleId: string;
    actionsModuleId: string;
    cloudformationTemplate: string;
    typescriptOutput: string;
    buildProperties?: {
        external?: string[] | undefined;
        minify?: boolean | undefined;
        sourcemap?: boolean | undefined;
        target?: string | undefined;
    } | undefined;
    outputConfig?: {
        format?: "json" | "yaml" | undefined;
        yamlConfig?: {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        } | undefined;
    } | undefined;
    sourceTemplate?: string | undefined;
    typescriptConfig?: any;
    dispatcherDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
        batchSize?: number | undefined;
        maximumRetryAttempts?: number | undefined;
    } | undefined;
    handlerDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    } | undefined;
    lambdaDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    } | undefined;
    tableDefaults?: {
        enablePointInTimeRecovery?: boolean | undefined;
    } | undefined;
    useEfficientIndexes?: boolean | undefined;
    legacyEmptySortFieldBehavior?: boolean | undefined;
}>;
export type Config = z.infer<typeof ConfigSchema>;
export type InputConfig = z.input<typeof ConfigSchema>;
//# sourceMappingURL=config.d.ts.map